summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSven Eden <yamakuzure@gmx.net>2016-12-05 09:21:35 +0100
committerSven Eden <yamakuzure@gmx.net>2017-03-14 10:17:18 +0100
commit86e97d599f8b1ca379dce64fadac9b8f6b002ac5 (patch)
treea704bdd39da04a788ff367a5dd9fbddb6a82cb62
parentc7ec9e23fbb4203302389cf3a8a8da920e2a981f (diff)
Prep v220: Apply "Fixes to user and session saving"
-rw-r--r--src/login/logind-session-dbus.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/login/logind-session-dbus.c b/src/login/logind-session-dbus.c
index 563153e2d..b5ecc322f 100644
--- a/src/login/logind-session-dbus.c
+++ b/src/login/logind-session-dbus.c
@@ -714,9 +714,10 @@ int session_send_create_reply(Session *s, sd_bus_error *error) {
if (fifo_fd < 0)
return fifo_fd;
/* Update the session state file before we notify the client
* about the result. */
session_save(s);
+ user_save(s->user);
p = session_bus_path(s);
if (!p)
@@ -714,9 +714,10 @@ int session_send_create_reply(Session *s, sd_bus_error *error) {
if (fifo_fd < 0)
return fifo_fd;
- /* Update the session state file before we notify the client
+ /* Update the session and user state file before we notify the client
* about the result. */
session_save(s);